@@ -62,6 +62,8 @@ r_est <- function(y,r,trim,tt,qq1,qn1,qn,n,cf,xt,ct,thresh){
 }
 
 model <- function(r,trim,rep,it,qq1,cf,xt,ct,thresh,tt,qn1,n,qn,cc,yt,ty,k){
+
+output=list()
 vgraph=1
       if (max(r)==0){
           qq <- qq1;
@@ -96,7 +98,7 @@ vgraph=1
               titname="Confidence Interval Construction in Triple Threshold Model"
               xname="Thrid Threshold Parameter"}
           yname="Likelihood Ratio"
-          dev.new() 
+
           xxlim <- range(qq)
           yylim <- range(rbind(lr,cc))
           plot(qq,lr,lty=1,col=1,xlim=xxlim,ylim=yylim,type="l",ann=0)
@@ -147,24 +149,30 @@ vgraph=1
       cat (t(rrr), "\n")
       cat ("\n")
       cat ("Regime-independent Coefficients, standard errors, het standard errors,and t-stat", "\n")
-      beta=cbind(beta,beta[,1]/beta[,3])
+      beta=as.matrix(cbind(beta,c(beta[,1]/beta[,3])))
+
+      indep_beta=round(cbind(beta[1:k,]),4)
+      colnames(indep_beta)=c("Coeff", "std", "White","tstat")
       cat(" Coeff",  "      std",  "        White","      tstat", "\n")
-      beta <- format(beta, digits = 4, scientific = FALSE)
-      for (j in 1:k) cat (beta[j,], "\n")
+      betax <- format(beta, digits = 4, scientific = FALSE)
+      for (j in 1:k) cat (betax[j,], "\n")
       cat ("\n")
       cat ("Regime-dependent Coefficients, standard errors, het standard errors,and t-stat", "\n")
 
-      for (j in (k+1):nrow(beta)) cat (beta[j,], "\n")
+      for (j in (k+1):nrow(beta)) cat (betax[j,], "\n")
+      beta=round(beta,4)
+      dep_beta=as.matrix(cbind(beta[((k+1):nrow(beta)),]),,4)
+      colnames(dep_beta)=c("Coeff", "std", "White","tstat")
       cat ("\n")
       cat ("\n")
+
       if (rep > 0){
           xx <- cbind(xt,ct)
           if (max(rr) != 0){
               for (j in 1:nrow(rr))
       tmp4=NULL;for (i in 1:ncol(cf)) {tmp4=cbind(tmp4,tr(cf[,i]*(thresh < rr[j]),tt,n))} ;xx <-cbind(xx,tmp4) 
-
-
           }
+          
           yp <- xx%*%qr.solve(xx,yt)
           e <- yt-yp
           sse0 <- t(e)%*%e
@@ -188,7 +196,7 @@ vgraph=1
               if (max(r) != 0){
                   for (jj in 1:length(r)){
                       sse0 <- sse1
-                      out <- r_est(yb,rrr,trim,tt,qq1,qn1,qn,n,cf,xt,ct,thresh)
+               out <- r_est(yb,rrr,trim,tt,qq1,qn1,qn,n,cf,xt,ct,thresh)
                       sse1 <- out$sse_b
                       rhat_b <- out$rhat_b
                       rrr <- rbind(rrr,rhat_b)
@@ -200,28 +208,35 @@ vgraph=1
           }
           cat ("\n")
           cat ("\n")
-          stats <- as.matrix(sort(stats))
+          stats <- round(as.matrix(sort(stats)),4)
           crits <- as.matrix(stats[ceiling(rbind(.90,.95,.99)*rep)])
           cat ("Number of Bootstrap replications   ", rep, "\n")
           cat ("Bootstrap p-value                  ", mean(stats > as.vector(lrt)), "\n")
+          
           cat ("Critical Values   ", crits[1], crits[2], crits[3], "\n")
           cat ("\n")
           cat ("\n")
-      }
-      rhat
+pv=mean(stats > as.vector(lrt))     
+#output=list(indepBeta=indep_beta,depBeta=dep_beta,th=rhat)
+output=list(indepBeta=indep_beta,depBeta=dep_beta,th=sort(rhat),LR=as.numeric(lrt),CV=c(crits[1], crits[2], crits[3]),PV=pv)
+return(output)
+ }
+
+
+
+
+
 }
 
 ptm <- function(dep,ind1,ind2,d,bootn,trimn,qn,conf_lev,t,n){
 
-boot_1=bootn[1]
-boot_2=bootn[2]
-boot_3=bootn[3]
-trim_1=trimn[1]
-trim_2=trimn[2]
-trim_3=trimn[3]
+boot_1=bootn[1];boot_2=bootn[2];boot_3=bootn[3]
+trim_1=trimn[1];trim_2=trimn[2];trim_3=trimn[3]
 
-tt <- t
-ty <- n*tt
+#tt <- t-max_lag
+tt=t
+ty=n*tt
+#ty <- n*(t-max_lag-1)
 
 y  <- dep
 cf=ind1
@@ -231,7 +246,8 @@ for (j in 1:ncol(cf)) { ct=cbind(ct,tr(cf[,j],tt,n)) }
 
 d1 <- d   # set to threshold variable
 yt <- tr(y,tt,n)
-
+#q1 <- ind2
+#x <- cbind(q1,(q1^2),(q1^3),d1,(q1*d1))
 x<-ind2
 k <- ncol(x)
 xt <- matrix(c(0),nrow=nrow(yt),ncol=k)
@@ -245,7 +261,6 @@ qq1 <- as.matrix(dd[floor(sq*nrow(dd))])
 qn1 <- nrow(qq1)
 cc <- -2*log(1-sqrt(conf_lev))
 
-#for (i in 1:1){
 cat ("Number of Firms        ", n, "\n")
 cat ("Number of Years used   ", tt, "\n")
 cat ("Total Observations     ", ty, "\n")
@@ -276,25 +291,29 @@ cat ("Double Threshold Model", "\n")
 cat ("Trimming Percentage    ", trim_2, "\n")
 cat ("\n")
 cat ("First Iteration", "\n")
-rhat2 <- model(rhat1,trim_2,boot_2,2,qq1,cf,xt,ct,thresh,tt,qn1,n,qn,cc,yt,ty,k)
+rhat2 <- model(rhat1$th,trim_2,boot_2,2,qq1,cf,xt,ct,thresh,tt,qn1,n,qn,cc,yt,ty,k)
 cat ("Second Iteration", "\n")
-rhat1 <- model(rhat2,trim_2,0,1,qq1,cf,xt,ct,thresh,tt,qn1,n,qn,cc,yt,ty,k)
+rhat1x <- model(rhat2$th,trim_2,1,1,qq1,cf,xt,ct,thresh,tt,qn1,n,qn,cc,yt,ty,k)
 cat ("\n")
 cat ("\n")
 cat ("*******************************************************", "\n")
 cat ("\n")
 cat ("\n")
-
 cat ("Triple Threshold Model", "\n")
 cat ("Trimming Percentage    ", trim_3, "\n")
 cat ("\n")
-rhat3 <- model(rbind(rhat1,rhat2),trim_3,boot_3,3,qq1,cf,xt,ct,thresh,tt,qn1,n,qn,cc,yt,ty,k)
+rhat3 <- model(c(rhat1$th,rhat2$th),trim_3,boot_3,3,qq1,cf,xt,ct,thresh,tt,qn1,n,qn,cc,yt,ty,k)
 cat ("\n")
 cat ("\n")
 cat ("*******************************************************", "\n")
 cat ("\n")
 cat ("\n")
-#}
+output1=list(indepBeta=rhat1$indepBeta,depBeta=rhat1$depBeta,threshold=rhat1x$th,LR=rhat1$LR,PValue=rhat1$PV,CV=rhat1$CV)
+output2=list(indepBeta=rhat2$indepBeta,depBeta=rhat2$depBeta,threshold=sort(c(rhat1x$th,rhat2$th)),LR=rhat2$LR,PValue=rhat2$PV,CV=rhat2$CV)
+output3=list(indepBeta=rhat3$indepBeta,depBeta=rhat3$depBeta,threshold=sort(c(rhat1x$th,rhat2$th,rhat3$th)),LR=rhat3$LR,PValue=rhat3$PV,CV=rhat3$CV)
+Output=list(output1,output2,output3)
+return(Output)
+
 }
 
 
